@@ -1,18 +1,20 @@
 package Reply::Plugin::DataPrinter;
 our $AUTHORITY = 'cpan:DOY';
-$Reply::Plugin::DataPrinter::VERSION = '0.40';
+$Reply::Plugin::DataPrinter::VERSION = '0.41';
 use strict;
 use warnings;
 # ABSTRACT: format results using Data::Printer
 
 use base 'Reply::Plugin';
 
-use Data::Printer alias => 'p', colored => 1;
+use Data::Printer alias => 'p', colored => 1, return_value => 'dump';
 
 
 sub mangle_result {
     my ($self, @result) = @_;
-    return p(@result, return_value => 'dump');
+    return unless @result;
+    ( @result == 1 ) && return p($result[0]);
+    return p(@result);
 }
 
 1;
@@ -29,7 +31,7 @@ Reply::Plugin::DataPrinter - format results using Data::Printer
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
