@@ -1,6 +1,6 @@
 package Reply::Plugin::Defaults;
 our $AUTHORITY = 'cpan:DOY';
-$Reply::Plugin::Defaults::VERSION = '0.40';
+$Reply::Plugin::Defaults::VERSION = '0.41';
 # XXX Eval::Closure imposes its own hints on things that are eval'ed at the
 # moment, but this may be fixed in the future
 BEGIN {
@@ -93,6 +93,13 @@ sub command_q {
     return '';
 }
 
+sub command_vars {
+    my $self = shift;
+
+    my %env = map { %$_ } $self->publish('lexical_environment');
+    return '(' . join(', ', map { qq<'$_'> } keys %env) . ')';
+}
+
 sub loop {
     my $self = shift;
     my ($continue) = @_;
@@ -106,6 +113,7 @@ sub loop {
 
   new
   command_q
+  command_vars
 
 =end Pod::Coverage
 
